@@ -16,15 +16,16 @@
 
 #include <QSharedDataPointer>
 #include <QString>
+#include <QStringList>
 
 #include "holiday.h"
 
 class QDate;
-class QStringList;
 class QFileInfo;
 
 namespace KHolidays
 {
+class HolidayRegionPrivate;
 
 /** Represents a holiday region. */
 class KHOLIDAYS_EXPORT HolidayRegion
@@ -46,11 +47,29 @@ public:
      */
     explicit HolidayRegion(const QFileInfo &regionFile);
 
+    /** Copy constructor.
+     *  @since 5.77
+     */
+    HolidayRegion(const HolidayRegion &);
+    /** Move constructor.
+     *  @since 5.77
+     */
+    HolidayRegion(HolidayRegion &&);
+
     /**
      * Destroys the holidays object.
      */
     ~HolidayRegion();
 
+    /** Assignment operator.
+     *  @since 5.77
+     */
+    HolidayRegion &operator=(const HolidayRegion &);
+    /** Move Assignment operator.
+     *  @since 5.77
+     */
+    HolidayRegion &operator=(HolidayRegion &&);
+
     /**
      * @since 4.5
      *
@@ -72,12 +91,13 @@ public:
      * If a required country/language is not provided then the current KDE
      * country/lanaguage is used.
      *
-     * @param country The country to find a default Holiday Region for
+     * @param country The country or region to find a default Holiday Region for.
+     *   This can be either an ISO 3166-1 or ISO 3166-2 code.
      * @param language The lanaguage to find a default Holiday Region for
      * @return the full region code of the default file
+     * @warning This methods is expensive as it involves parsing all holiday definition files.
      */
-    static QString defaultRegionCode(const QString &country = QString(),
-                                     const QString &language = QString());
+    static QString defaultRegionCode(const QString &country = QString(), const QString &language = QString());
 
     /**
      * @since 4.5
@@ -117,6 +137,8 @@ public:
      *
      * @param regionCode The code for the Holiday Region.
      * @return the full region code of the file
+     * @warning This methods is expensive as it involves parsing the corresponding holiday
+     *   definition file. Prefer HolidayRegion::countryCode().
      */
     static QString countryCode(const QString &regionCode);
 
@@ -142,6 +164,8 @@ public:
      *
      * @param regionCode The code for the Holiday Region.
      * @return the language code of the file
+     * @warning This methods is expensive as it involves parsing the corresponding holiday
+     *   definition file. Prefer HolidayRegion::languageCode().
      */
     static QString languageCode(const QString &regionCode);
 
@@ -222,10 +246,7 @@ public:
     static bool isValid(const QString &regionCode);
 
 private:
-    Q_DISABLE_COPY(HolidayRegion)
-
-    class HolidayRegionPrivate;
-    HolidayRegionPrivate *const d;
+    QExplicitlySharedDataPointer<HolidayRegionPrivate> d;
 };
 
 }
